==> rivendell-2.2.0.tar.gz: rivendell-2.2.0/rdairplay/rdairplay_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation>Event editieren</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Starte um:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Aktion wenn das vorherige Event noch läuft</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Sofort starten</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Als nächstes</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Warte bis zu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation>Start-Übergangstyp:</translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation>Kein faden beim Segue Out</translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation>&amp;Anhören</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation>Marker editieren</translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation>Track editieren</translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation>Log-Track editieren</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Übergang, wenn vorheriger Cart eher endet</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation>Doppelte Startzeit</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation>Es existiert bereits ein Event mit dieser Startzeit!</translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation>CA. ZEIT</translation>
    </message>
    <message>
        <source>LEN</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation>ÜBERG</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CART</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>KÜNSTLER</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>ZEIT</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>KUNDE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENTUR</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation>LABEL</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation>LINE ID</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>ZÄHLER</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>STATUS</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation>Als
Nächstes</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Scrollen</translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation>Log
erneuern</translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation>Log
auswählen</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Log existiert</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Log existiert bereits!</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- ende des Logs ---</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PLAY</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOP</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKER</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>TRACK</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[traffic import]</translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation>CHAIN TO</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CART NICHT GEFUNDEN]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[KEIN GÜLTIGER CUT VERFÜGBAR]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[KEIN AUDIO VERFÜGBAR]</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation>Laufzeit</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Nächster Stop:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Log Ende:</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Ausgewählt:</translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation>Anfang
vorhören</translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation>Ende
vorhören</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation>Log auswählen</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVICE</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <source>Unload</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;Als</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation>Log umbenennen</translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation>STOP</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PLAY</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CART NICHT GEFUNDEN]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[KEIN AUDIO VERFÜGBAR]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[KEIN GÜLTIGER CUT VERFÜGBAR]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKER</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>TRACK</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[traffic import]</translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation>CHAIN</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation>RDAirPlay</translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation>Mehrere Instanzen sind nicht erlaubt!</translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation>RDAirPlay - Host:</translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation>Datenbankfehler</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>HINZUFÜGEN</translation>
    </message>
    <message>
        <source>DEL</source>
        <translation>DEL</translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation>VERSCHIEBEN</translation>
    </message>
    <message>
        <source>COPY</source>
        <translation>KOPIEREN</translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation>Main Log
[--]</translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation>Aux 1 Log
[--]</translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation>Aux 2 Log
[--]</translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation>Sound
Panel</translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation>Main Log</translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation>Aux 1 Log</translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation>Aux 2 Log</translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation>LOG
AKTUALISIERT</translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation>RDAirPlay verlassen?</translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation>Operationsmodus</translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation>LiveAssist</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation>Nächster Zeit-Start</translation>
    </message>
    <message>
        <source>On Time</source>
        <translation>Pünktlich</translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation>Nächste Zeit-Start [--:--:--]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOP</translation>
    </message>
    <message>
        <source>PAUSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RESUME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WHERE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DELETE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TO?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation>Nächster Stop [keiner]</translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation>Nächster Stop</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Gestoppt</translation>
    </message>
</context>
</TS>

==> rivendell-2.5.0.tar.gz: rivendell-2.5.0/rdairplay/rdairplay_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation>Event editieren</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Starte um:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Aktion wenn das vorherige Event noch läuft</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Sofort starten</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Als nächstes</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Warte bis zu</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation>Start-Übergangstyp:</translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation>Kein faden beim Segue Out</translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation>&amp;Anhören</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation>Marker editieren</translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation>Track editieren</translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation>Log-Track editieren</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Übergang, wenn vorheriger Cart eher endet</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation>Doppelte Startzeit</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation>Es existiert bereits ein Event mit dieser Startzeit!</translation>
    </message>
</context>
<context>
    <name>HourSelector</name>
    <message>
        <source>12a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation>CA. ZEIT</translation>
    </message>
    <message>
        <source>LEN</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation>ÜBERG</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CART</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>KÜNSTLER</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>ZEIT</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>KUNDE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENTUR</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation>LABEL</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation>LINE ID</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>ZÄHLER</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>STATUS</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation>Als
Nächstes</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Scrollen</translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation>Log
erneuern</translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation>Log
auswählen</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Log existiert</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Log existiert bereits!</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- ende des Logs ---</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PLAY</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOP</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKER</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>TRACK</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[traffic import]</translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation>CHAIN TO</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CART NICHT GEFUNDEN]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[KEIN GÜLTIGER CUT VERFÜGBAR]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[KEIN AUDIO VERFÜGBAR]</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation>Laufzeit</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Nächster Stop:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Log Ende:</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Ausgewählt:</translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation>Anfang
vorhören</translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation>Ende
vorhören</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation>Log auswählen</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVICE</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <source>Unload</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;Als</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation>Log umbenennen</translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation>STOP</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PLAY</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[CART NICHT GEFUNDEN]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[KEIN AUDIO VERFÜGBAR]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[KEIN GÜLTIGER CUT VERFÜGBAR]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKER</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>TRACK</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LINK</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[traffic import]</translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation>CHAIN</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation>RDAirPlay</translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation>Mehrere Instanzen sind nicht erlaubt!</translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation type="obsolete">RDAirPlay - Host:</translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation>Datenbankfehler</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>HINZUFÜGEN</translation>
    </message>
    <message>
        <source>DEL</source>
        <translation>DEL</translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation>VERSCHIEBEN</translation>
    </message>
    <message>
        <source>COPY</source>
        <translation>KOPIEREN</translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation>Main Log
[--]</translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation>Aux 1 Log
[--]</translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation>Aux 2 Log
[--]</translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation>Sound
Panel</translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation>Main Log</translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation>Aux 1 Log</translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation>Aux 2 Log</translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation>LOG
AKTUALISIERT</translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation>RDAirPlay verlassen?</translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation>Operationsmodus</translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation>LiveAssist</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation>Nächster Zeit-Start</translation>
    </message>
    <message>
        <source>On Time</source>
        <translation>Pünktlich</translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation>Nächste Zeit-Start [--:--:--]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOP</translation>
    </message>
    <message>
        <source>PAUSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RESUME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WHERE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DELETE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TO?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation>Nächster Stop [keiner]</translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation>Nächster Stop</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Gestoppt</translation>
    </message>
</context>
</TS>
